@@ -37,7 +37,7 @@ class InterpCubic(InterpAlgorithm):
         **kwargs : dict
             Interpolator-specific options to pass onward.
         """
-        super(InterpCubic, self).__init__(grid, values, interp)
+        super().__init__(grid, values, interp)
         self.second_derivs = None
         self.k = 4
         self._name = 'cubic'
