@@ -419,7 +419,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(NameError) as ctx:
             dpc.add_product('c')
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: "
                          "Multiple definition of output 'c'.")
 
     def test_input_as_output(self):
@@ -428,7 +428,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(NameError) as ctx:
             dpc.add_product('a', 'b', 'c')
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: 'a' specified as "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: 'a' specified as "
                          "an output, but it has already been defined as an input.")
 
     def test_output_as_input_a(self):
@@ -437,7 +437,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(NameError) as ctx:
             dpc.add_product('z', 'c', 'b')
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: 'c' specified as "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: 'c' specified as "
                          "an input, but it has already been defined as an output.")
 
     def test_output_as_input_b(self):
@@ -446,7 +446,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(NameError) as ctx:
             dpc.add_product('z', 'b', 'c')
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: 'c' specified as "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: 'c' specified as "
                          "an input, but it has already been defined as an output.")
 
     def test_a_vec_size_mismatch(self):
@@ -455,7 +455,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(ValueError) as ctx:
             dpc.add_product('z', 'a', 'y', vec_size=10)
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: "
                          "Conflicting vec_size=10 specified for input 'a', "
                          "which has already been defined with vec_size=1.")
 
@@ -465,7 +465,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(ValueError) as ctx:
             dpc.add_product('z', 'a', 'y', length=10)
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: "
                          "Conflicting length=10 specified for input 'a', "
                          "which has already been defined with length=3.")
 
@@ -475,7 +475,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(ValueError) as ctx:
             dpc.add_product('z', 'a', 'b',a_units='ft')
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: "
                          "Conflicting units 'ft' specified for input 'a', "
                          "which has already been defined with units 'None'.")
 
@@ -485,7 +485,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(ValueError) as ctx:
             dpc.add_product('z', 'x', 'b', vec_size=10)
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: "
                          "Conflicting vec_size=10 specified for input 'b', "
                          "which has already been defined with vec_size=1.")
 
@@ -495,7 +495,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(ValueError) as ctx:
             dpc.add_product('z', 'x', 'b', length=10)
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: "
                          "Conflicting length=10 specified for input 'b', "
                          "which has already been defined with length=3.")
 
@@ -505,7 +505,7 @@ class TestMultipleErrors(unittest.TestCase):
         with self.assertRaises(ValueError) as ctx:
             dpc.add_product('z', 'a', 'b', b_units='ft')
 
-        self.assertEqual(str(ctx.exception), "DotProductComp: "
+        self.assertEqual(str(ctx.exception), "<class DotProductComp>: "
                          "Conflicting units 'ft' specified for input 'b', "
                          "which has already been defined with units 'None'.")
 
