@@ -105,9 +105,9 @@ class ImplicitComponent(Component):
             try:
                 with self._unscaled_context(outputs=[self._outputs], residuals=[self._residuals]):
                     if complex_step:
-                        self._inputs.set_complex_step_mode(False, keep_real=True)
-                        self._outputs.set_complex_step_mode(False, keep_real=True)
-                        self._residuals.set_complex_step_mode(False, keep_real=True)
+                        self._inputs.set_complex_step_mode(False)
+                        self._outputs.set_complex_step_mode(False)
+                        self._residuals.set_complex_step_mode(False)
 
                     with self._call_user_function('guess_nonlinear', protect_residuals=True):
                         if self._discrete_inputs or self._discrete_outputs:
@@ -117,13 +117,9 @@ class ImplicitComponent(Component):
                             self.guess_nonlinear(self._inputs, self._outputs, self._residuals)
             finally:
                 if complex_step:
-                    # Note: passing in False swaps back to the complex vector, which is valid since
-                    # the inputs and residuals value cannot be edited.
-                    self._inputs.set_complex_step_mode(False)
-                    self._inputs._under_complex_step = True
+                    self._inputs.set_complex_step_mode(True)
                     self._outputs.set_complex_step_mode(True)
-                    self._residuals.set_complex_step_mode(False)
-                    self._residuals._under_complex_step = True
+                    self._residuals.set_complex_step_mode(True)
 
     def _apply_linear(self, jac, vec_names, rel_systems, mode, scope_out=None, scope_in=None):
         """
