@@ -164,7 +164,7 @@ class TestIndepVarComp(unittest.TestCase):
             prob = om.Problem(om.IndepVarComp()).setup()
         except Exception as err:
             self.assertEqual(str(err),
-                "IndepVarComp (<model>): No outputs (independent variables) have been declared. They must either be declared during "
+                "<model> <class IndepVarComp>: No outputs (independent variables) have been declared. They must either be declared during "
                 "instantiation or by calling add_output or add_discrete_output afterwards.")
         else:
             self.fail('Exception expected.')
@@ -215,14 +215,14 @@ class TestIndepVarComp(unittest.TestCase):
         self.assertEqual(prob.get_val('val_y'), 2.5)
 
     def test_ivc_deprecations(self):
-        msg = "IndepVarComp (p1): The '{}' argument was used when adding output '{}'. " + \
+        msg = "'p1' <class IndepVarComp>: The '{}' argument was used when adding output '{}'. " + \
               "This argument has been deprecated and will be removed in a future version."
 
-        # ref, ref0
         prob = om.Problem()
 
         indep = prob.model.add_subsystem('p1', om.IndepVarComp())
 
+        # ref, ref0
         with assert_warnings([(DeprecationWarning, msg.format('ref', 'a')),
                               (DeprecationWarning, msg.format('ref0', 'a'))]):
             indep.add_output('a', 12., ref=0.0, ref0=1.)
