@@ -4,8 +4,8 @@ import numpy as np
 import time
 import random
 
-from openmdao.api import Group, ParallelGroup, Problem, IndepVarComp, \
-    ExecComp, PETScVector
+import openmdao.api as om
+
 from openmdao.utils.mpi import MPI
 from openmdao.utils.assert_utils import assert_near_equal
 
@@ -13,47 +13,48 @@ if MPI:
     from openmdao.api import PETScVector
     vector_class = PETScVector
     try:
-        from openmdao.api import pyOptSparseDriver
+        from pyoptsparse import Optimization as pyoptsparse_opt
     except ImportError:
-        pyOptSparseDriver = None
+        pyoptsparse_opt = None
+
 else:
     PETScVector = None
-    pyOptSparseDriver = None
+    pyoptsparse_opt = None
 
 
-class Mygroup(Group):
+class Mygroup(om.Group):
 
     def setup(self):
-        self.add_subsystem('indep_var_comp', IndepVarComp('x'), promotes=['*'])
-        self.add_subsystem('Cy', ExecComp('y=2*x'), promotes=['*'])
-        self.add_subsystem('Cc', ExecComp('c=x+2'), promotes=['*'])
+        self.add_subsystem('indep_var_comp', om.IndepVarComp('x'), promotes=['*'])
+        self.add_subsystem('Cy', om.ExecComp('y=2*x'), promotes=['*'])
+        self.add_subsystem('Cc', om.ExecComp('c=x+2'), promotes=['*'])
 
         self.add_design_var('x')
         self.add_constraint('c', lower=-3.)
 
 
-@unittest.skipUnless(MPI and PETScVector and pyOptSparseDriver,
+@unittest.skipUnless(MPI and PETScVector and pyoptsparse_opt,
                      "MPI, PETSc and pyoptsparse are required.")
 class RemoteVOITestCase(unittest.TestCase):
 
     N_PROCS = 2
 
     def test_remote_voi(self):
-        prob = Problem()
+        prob = om.Problem()
 
-        par = prob.model.add_subsystem('par', ParallelGroup())
+        par = prob.model.add_subsystem('par', om.ParallelGroup())
 
         prob.model.par.add_subsystem('G1', Mygroup())
         prob.model.par.add_subsystem('G2', Mygroup())
 
-        prob.model.add_subsystem('Obj', ExecComp('obj=y1+y2'))
+        prob.model.add_subsystem('Obj', om.ExecComp('obj=y1+y2'))
 
         prob.model.connect('par.G1.y', 'Obj.y1')
         prob.model.connect('par.G2.y', 'Obj.y2')
 
         prob.model.add_objective('Obj.obj')
 
-        prob.driver = pyOptSparseDriver()
+        prob.driver = om.pyOptSparseDriver()
         prob.driver.options['optimizer'] = 'SLSQP'
         prob.setup()
 
