@@ -270,4 +270,7 @@ def record_system_options(problem):
 
         for recorder in recorders:
             for sub in problem.model.system_iter(recurse=True, include_self=True):
-                recorder.record_metadata_system(sub)
+                if problem._run_counter >= 1:
+                    recorder.record_metadata_system(sub, problem._run_counter)
+                else:
+                    recorder.record_metadata_system(sub)
