@@ -32,7 +32,7 @@ class LinearBlockJac(BlockLinearSolver):
             for vec_name in vec_names:
                 b_vec = system._vectors['residual'][vec_name]
                 b_vec *= -1.0
-                b_vec._data += self._rhs_vecs[vec_name]
+                b_vec += self._rhs_vecs[vec_name]
 
             for subsys in subs:
                 subsys._solve_linear(vec_names, mode, self._rel_systems)
@@ -48,7 +48,7 @@ class LinearBlockJac(BlockLinearSolver):
 
                 b_vec = system._vectors['output'][vec_name]
                 b_vec *= -1.0
-                b_vec._data += self._rhs_vecs[vec_name]
+                b_vec += self._rhs_vecs[vec_name]
 
             for subsys in subs:
                 subsys._solve_linear(vec_names, mode, self._rel_systems)
