@@ -13,7 +13,7 @@ from openmdao.test_suite.components.double_sellar import DoubleSellar
 from openmdao.test_suite.components.implicit_newton_linesearch \
     import ImplCompTwoStates, ImplCompTwoStatesArrays
 from openmdao.test_suite.components.sellar import SellarDis1, SellarDis2withDerivatives
-from openmdao.utils.assert_utils import assert_near_equal
+from openmdao.utils.assert_utils import assert_near_equal, assert_warning
 
 
 class TestArmejoGoldsteinBounds(unittest.TestCase):
@@ -442,23 +442,19 @@ class TestBoundsEnforceLSArrayBounds(unittest.TestCase):
         for ind in range(3):
             assert_near_equal(top['comp.z'][ind], [1.5], 1e-8)
 
+        msg = (f"'comp.z' exceeds lower bounds\n  Val: [1.33333333 1.33333333 1.33333333]\n  Upper: [1.5 1.5 1.5]\n")
+        with assert_warning(UserWarning, msg):
+            top.run_model()
+
+        top.setup()
         # Test upper bounds: should go to the minimum upper bound and stall
         top['px.x'] = 0.5
         top['comp.y'] = 0.
         top['comp.z'] = 2.4
 
-        stdout = sys.stdout
-        strout = StringIO()
-
-        sys.stdout = strout
-        try:
+        msg = (f"'comp.z' exceeds upper bounds\n  Val: [2.66666667 2.66666667 2.66666667]\n  Upper: [2.6  2.5  2.65]\n")
+        with assert_warning(UserWarning, msg):
             top.run_model()
-        finally:
-            sys.stdout = stdout
-
-        txt = strout.getvalue()
-
-        self.assertTrue("'comp.z' exceeds upper bound" in txt)
 
         for ind in range(3):
             assert_near_equal(top['comp.z'][ind], [2.5], 1e-8)
