@@ -2,8 +2,6 @@ import unittest
 
 import numpy as np
 
-import openmdao.api as om
-from openmdao.test_suite.components.sellar import SellarDis1, SellarDis2
 from openmdao.utils.assert_utils import assert_near_equal
 
 
@@ -21,10 +19,6 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
             """
 
             def setup(self):
-                indeps = self.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
-                indeps.add_output('x', 1.0)
-                indeps.add_output('z', np.array([5.0, 2.0]))
-
                 cycle = self.add_subsystem('cycle', om.Group(), promotes=['*'])
                 cycle.add_subsystem('d1', SellarDis1(),
                                     promotes_inputs=['x', 'z', 'y2'],
@@ -33,6 +27,9 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
                                     promotes_inputs=['z', 'y1'],
                                     promotes_outputs=['y2'])
 
+                cycle.set_input_defaults('x', 1.0)
+                cycle.set_input_defaults('z', np.array([5.0, 2.0]))
+
                 # Nonlinear Block Gauss Seidel is a gradient free solver
                 cycle.nonlinear_solver = om. NonlinearBlockGS()
 
@@ -51,12 +48,12 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
 
         prob.setup()
 
-        prob['x'] = 2.
-        prob['z'] = [-1., -1.]
+        prob.set_val('x', 2.0)
+        prob.set_val('z', [-1., -1.])
 
         prob.run_model()
 
-        assert_near_equal((prob['y1'][0], prob['y2'][0], prob['obj'][0], prob['con1'][0], prob['con2'][0]),
+        assert_near_equal((prob.get_val('y1')[0], prob.get_val('y2')[0], prob.get_val('obj')[0], prob.get_val('con1')[0], prob.get_val('con2')[0]),
                          (2.10951651, -0.54758253,  6.8385845,  1.05048349, -24.54758253), 1e-5)
 
     def test_sellar_mda_promote_in_configure(self):
@@ -72,10 +69,6 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
 
             def setup(self):
                 # set up model hierarchy
-                indeps = self.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
-                indeps.add_output('x', 1.0)
-                indeps.add_output('z', np.array([5.0, 2.0]))
-
                 cycle = self.add_subsystem('cycle', om.Group())
                 cycle.add_subsystem('d1', SellarDis1())
                 cycle.add_subsystem('d2', SellarDis2())
@@ -92,6 +85,7 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
                 # connect everything via promotes
                 self.cycle.promotes('d1', inputs=['x', 'z', 'y2'], outputs=['y1'])
                 self.cycle.promotes('d2', inputs=['z', 'y1'], outputs=['y2'])
+
                 self.promotes('cycle', any=['*'])
 
                 self.promotes('obj_cmp', any=['x', 'z', 'y1', 'y2', 'obj'])
@@ -104,12 +98,12 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
 
         prob.setup()
 
-        prob['x'] = 2.
-        prob['z'] = [-1., -1.]
+        prob.set_val('x', 2.0)
+        prob.set_val('z', [-1., -1.])
 
         prob.run_model()
 
-        assert_near_equal((prob['y1'][0], prob['y2'][0], prob['obj'][0], prob['con1'][0], prob['con2'][0]),
+        assert_near_equal((prob.get_val('y1')[0], prob.get_val('y2')[0], prob.get_val('obj')[0], prob.get_val('con1')[0], prob.get_val('con2')[0]),
                          (2.10951651, -0.54758253,  6.8385845,  1.05048349, -24.54758253), 1e-5)
 
     def test_sellar_mda_connect(self):
@@ -124,27 +118,28 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
             """
 
             def setup(self):
-                indeps = self.add_subsystem('indeps', om.IndepVarComp())
-                indeps.add_output('x', 1.0)
-                indeps.add_output('z', np.array([5.0, 2.0]))
-
-                cycle = self.add_subsystem('cycle', om.Group())
-                cycle.add_subsystem('d1', SellarDis1())
-                cycle.add_subsystem('d2', SellarDis2())
+                cycle = self.add_subsystem('cycle', om.Group(),
+                                           promotes_inputs=['x', 'z'])
+                cycle.add_subsystem('d1', SellarDis1(),
+                                    promotes_inputs=['x', 'z'])
+                cycle.add_subsystem('d2', SellarDis2(),
+                                    promotes_inputs=['z'])
                 cycle.connect('d1.y1', 'd2.y1')
                 cycle.connect('d2.y2', 'd1.y2')
 
+                cycle.set_input_defaults('x', 1.0)
+                cycle.set_input_defaults('z', np.array([5.0, 2.0]))
+
                 # Nonlinear Block Gauss Seidel is a gradient free solver
                 cycle.nonlinear_solver = om.NonlinearBlockGS()
 
                 self.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                          z=np.array([0.0, 0.0]), x=0.0))
+                                                          z=np.array([0.0, 0.0]), x=0.0),
+                                   promotes_inputs=['x', 'z'])
 
                 self.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'))
                 self.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'))
 
-                self.connect('indeps.x', ['cycle.d1.x', 'obj_cmp.x'])
-                self.connect('indeps.z', ['cycle.d1.z', 'cycle.d2.z', 'obj_cmp.z'])
                 self.connect('cycle.d1.y1', ['obj_cmp.y1', 'con_cmp1.y1'])
                 self.connect('cycle.d2.y2', ['obj_cmp.y2', 'con_cmp2.y2'])
 
@@ -153,12 +148,12 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
 
         prob.setup()
 
-        prob['indeps.x'] = 2.
-        prob['indeps.z'] = [-1., -1.]
+        prob.set_val('x', 2.0)
+        prob.set_val('z', [-1., -1.])
 
         prob.run_model()
 
-        assert_near_equal((prob['cycle.d1.y1'][0], prob['cycle.d2.y2'][0], prob['obj_cmp.obj'][0], prob['con_cmp1.con1'][0], prob['con_cmp2.con2'][0]),
+        assert_near_equal((prob.get_val('cycle.d1.y1')[0], prob.get_val('cycle.d2.y2')[0], prob.get_val('obj_cmp.obj')[0], prob.get_val('con_cmp1.con1')[0], prob.get_val('con_cmp2.con2')[0]),
                          (2.10951651, -0.54758253, 6.8385845, 1.05048349, -24.54758253), 1e-5)
 
 
@@ -174,27 +169,27 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
             """
 
             def setup(self):
-                indeps = self.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
-                indeps.add_output('x', 1.0)
-                indeps.add_output('z', np.array([5.0, 2.0]))
-
                 cycle = self.add_subsystem('cycle', om.Group(), promotes=['*'])
-                cycle.add_subsystem('d1', SellarDis1())
-                cycle.add_subsystem('d2', SellarDis2())
+                cycle.add_subsystem('d1', SellarDis1(),
+                                    promotes_inputs=['x', 'z'])
+                cycle.add_subsystem('d2', SellarDis2(),
+                                    promotes_inputs=['z'])
                 cycle.connect('d1.y1', 'd2.y1')
                 cycle.connect('d2.y2', 'd1.y2')
 
+                cycle.set_input_defaults('x', 1.0)
+                cycle.set_input_defaults('z', np.array([5.0, 2.0]))
+
                 # Nonlinear Block Gauss Seidel is a gradient free solver
                 cycle.nonlinear_solver = om.NonlinearBlockGS()
 
                 self.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                          z=np.array([0.0, 0.0]), x=0.0))
+                                                          z=np.array([0.0, 0.0]), x=0.0),
+                                   promotes_inputs=['x', 'z'])
 
                 self.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'))
                 self.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'))
 
-                self.connect('x', ['d1.x', 'obj_cmp.x'])
-                self.connect('z', ['d1.z', 'd2.z', 'obj_cmp.z'])
                 self.connect('d1.y1', ['con_cmp1.y1', 'obj_cmp.y1'])
                 self.connect('d2.y2', ['con_cmp2.y2', 'obj_cmp.y2'])
 
@@ -204,12 +199,12 @@ class TestSellarMDAPromoteConnect(unittest.TestCase):
 
         prob.setup()
 
-        prob['x'] = 2.
-        prob['z'] = [-1., -1.]
+        prob.set_val('x', 2.0)
+        prob.set_val('z', [-1., -1.])
 
         prob.run_model()
 
-        assert_near_equal((prob['d1.y1'][0], prob['d2.y2'][0], prob['obj_cmp.obj'][0], prob['con_cmp1.con1'][0], prob['con_cmp2.con2'][0]),
+        assert_near_equal((prob.get_val('cycle.d1.y1')[0], prob.get_val('cycle.d2.y2')[0], prob.get_val('obj_cmp.obj')[0], prob.get_val('con_cmp1.con1')[0], prob.get_val('con_cmp2.con2')[0]),
                          (2.10951651, -0.54758253, 6.8385845, 1.05048349, -24.54758253), 1e-5)
 
 
