@@ -4,10 +4,8 @@ A collection of utilities for file wrapping.
 Note: This is a work in progress.
 """
 
-from __future__ import print_function
 
 import re
-from six.moves import range
 
 from pyparsing import CaselessLiteral, Combine, OneOrMore, Optional, \
     TokenConverter, Word, nums, oneOf, printables, ParserElement, alphanums
