@@ -1,4 +1,7 @@
 """Define utils for use in testing."""
+import json
+
+import numpy as np
 
 
 def _new_setup(self):
@@ -74,3 +77,16 @@ def use_tempdirs(cls):
     setattr(cls, 'tearDown', _new_teardown)
 
     return cls
+
+
+class _ModelViewerDataTreeEncoder(json.JSONEncoder):
+    """Special JSON encoder for writing model viewer data."""
+
+    def default(self, obj):
+        if isinstance(obj, np.integer):
+            return int(obj)
+        elif isinstance(obj, np.floating):
+            return float(obj)
+        elif isinstance(obj, np.ndarray):
+            return obj.tolist()
+        return json.JSONEncoder.default(self, obj)
