@@ -82,7 +82,7 @@ def _convert_ndarray_to_support_nans_in_json(val):
     return(val_as_list)
 
 
-def _get_var_dict(system, typ, name):
+def _get_var_dict(system, typ, name, is_parallel):
     if name in system._var_discrete[typ]:
         meta = system._var_discrete[typ][name]
         is_discrete = True
@@ -114,7 +114,12 @@ def _get_var_dict(system, typ, name):
         var_dict['shape'] = str(meta['shape'])
 
     if 'distributed' in meta:
-        var_dict['distributed'] = meta['distributed']
+        var_dict['distributed'] = is_distributed = meta['distributed']
+    else:
+        is_distributed = False
+
+    if 'surrogate_name' in meta:
+        var_dict['surrogate_name'] = meta['surrogate_name']
 
     var_dict['is_discrete'] = is_discrete
 
@@ -125,10 +130,18 @@ def _get_var_dict(system, typ, name):
             var_dict['value'] = type(meta['value']).__name__
     else:
         if meta['value'].size < _MAX_ARRAY_SIZE_FOR_REPR_VAL:
-            if MPI:
-                var_dict['value'] = meta['value']
-            else:
+            if not MPI:
+                # get the current value
                 var_dict['value'] = _convert_ndarray_to_support_nans_in_json(system.get_val(name))
+            elif is_parallel or is_distributed:
+                # we can't access non-local values, so just get the initial value
+                var_dict['value'] = meta['value']
+                var_dict['initial_value'] = True
+            else:
+                # get the current value but don't try to get it from the source,
+                # which could be remote under MPI
+                val = system.get_val(name, from_src=False)
+                var_dict['value'] = _convert_ndarray_to_support_nans_in_json(val)
         else:
             var_dict['value'] = None
 
@@ -195,10 +208,10 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
         children = []
         for typ in ['input', 'output']:
             for abs_name in system._var_abs2meta[typ]:
-                children.append(_get_var_dict(system, typ, abs_name))
+                children.append(_get_var_dict(system, typ, abs_name, is_parallel))
 
             for prom_name in system._var_discrete[typ]:
-                children.append(_get_var_dict(system, typ, prom_name))
+                children.append(_get_var_dict(system, typ, prom_name, is_parallel))
 
     else:
         if isinstance(system, ParallelGroup):
